Dojo Toolkit
============

Toolkit for python coding dojos.
Source: https://github.com/grupy-sanca/dojo-toolkit

Features
--------
- Timer to determine the pilot's turn
- Run tests automatically and notify when people can or cannot talk

How to use
----------
``pip install dojo-toolkit``

``python -m dojo_toolkit /path/to/code/directory/``

Dependencies
------------
- Python 3
- `Libnotify <https://developer.gnome.org/libnotify>`_
